<!DOCTYPE html>
<html>
<head lang="en">
    <meta charset="UTF-8">
    <title></title>
    <link rel="stylesheet" href="{{ STATIC_URL }}zui/css/zui.lite.css"/>
</head>
<body>
<div class="container">
    <div class="panel-body">
        <div class="alert alert-success"><i class="icon-ok"></i> 成功!</div>
    </div>
</div>
<script>
    window.parent.location.reload();
</script>
</body>
</html>