/*!
 * Datetimepicker for Bootstrap
 * Copyright 2012 Stefan Petre
 * Licensed under the Apache License v2.0
 */
.datetimepicker {
  padding: 4px;
  margin-top: 1px;
  white-space: normal;
  border-radius: 4px;

  direction: ltr;
  }
.datetimepicker.datetimepicker-rtl {
  direction: rtl;
  }
.datetimepicker.datetimepicker-rtl table tr td span {
  float: right;
  }
.datetimepicker > div {
  display: none;
  }
.datetimepicker.minutes div.datetimepicker-minutes {
  display: block;
  }
.datetimepicker.hours div.datetimepicker-hours {
  display: block;
  }
.datetimepicker.days div.datetimepicker-days {
  display: block;
  }
.datetimepicker.months div.datetimepicker-months {
  display: block;
  }
.datetimepicker.years div.datetimepicker-years {
  display: block;
  }
.datetimepicker table {
  margin: 0;
  }
.datetimepicker table tr td.minute:hover {
  cursor: pointer;
  background: #eee;
  }
.datetimepicker table tr td.hour:hover {
  cursor: pointer;
  background: #eee;
  }
.datetimepicker table tr td.day:hover {
  cursor: pointer;
  background: #eee;
  }
.datetimepicker table tr td span {
  display: block;
  float: left;
  width: 23%;
  height: 54px;
  margin: 1%;
  line-height: 54px;
  cursor: pointer;
  border-radius: 4px;
  }
.datetimepicker table tr td span:hover {
  background: #eee;
  }
.datetimepicker table tr td span.old {
  color: #999;
  }
.datetimepicker .datetimepicker-hours span {
  height: 26px;
  line-height: 26px;
  }
.datetimepicker .datetimepicker-minutes span {
  height: 26px;
  line-height: 26px;
  }
.datetimepicker th.switch {
  width: 145px;
  }
.datetimepicker-inline {
  width: 220px;
  }
.datetimepicker-dropdown,
.datetimepicker-dropdown-left {
  top: 0;
  left: 0;
  }
[class*="datetimepicker-dropdown"]:before {
  position: absolute;
  display: inline-block;
  content: '';
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, .2);
  border-left: 7px solid transparent;
  }
[class*="datetimepicker-dropdown"]:after {
  position: absolute;
  display: inline-block;
  content: '';
  border-right: 6px solid transparent;
  border-bottom: 6px solid #fff;
  border-left: 6px solid transparent;
  }
[class*="datetimepicker-dropdown-top"]:before {
  display: inline-block;
  content: '';
  border-top: 7px solid #ccc;
  border-top-color: rgba(0, 0, 0, .2);
  border-right: 7px solid transparent;
  border-bottom: 0;
  border-left: 7px solid transparent;
  }
[class*="datetimepicker-dropdown-top"]:after {
  display: inline-block;
  content: '';
  border-top: 6px solid #fff;
  border-right: 6px solid transparent;
  border-bottom: 0;
  border-left: 6px solid transparent;
  }
.datetimepicker-dropdown-bottom-left:before {
  top: -7px;
  right: 6px;
  }
.datetimepicker-dropdown-bottom-left:after {
  top: -6px;
  right: 7px;
  }
.datetimepicker-dropdown-bottom-right:before {
  top: -7px;
  left: 6px;
  }
.datetimepicker-dropdown-bottom-right:after {
  top: -6px;
  left: 7px;
  }
.datetimepicker-dropdown-top-left:before {
  right: 6px;
  bottom: -7px;
  }
.datetimepicker-dropdown-top-left:after {
  right: 7px;
  bottom: -6px;
  }
.datetimepicker-dropdown-top-right:before {
  bottom: -7px;
  left: 6px;
  }
.datetimepicker-dropdown-top-right:after {
  bottom: -6px;
  left: 7px;
  }
.datetimepicker td,
.datetimepicker th {
  width: 22px;
  height: 20px;
  padding: 3px 0;
  text-align: center;
  border: none;
  border-radius: 4px;
  }
.table-striped .datetimepicker td,
.table-striped .datetimepicker th {
  background-color: transparent;
  }
.datetimepicker td.old,
.datetimepicker td.new {
  color: #999;
  }
.datetimepicker td.disabled,
.datetimepicker td.disabled:hover {
  color: #999;
  cursor: default;
  background: none;
  }
.datetimepicker td.day.today {
  color: #fff;
  background-color: #f1a325;
  border-color: #f1a325;
  border-color: rgba(0, 0, 0, .1) rgba(0, 0, 0, .1) rgba(0, 0, 0, .25);
  }
.datetimepicker td.day.active {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .25);
  background-color: #3280fc;
  border-color: #0462f7;
  border-color: rgba(0, 0, 0, .1) rgba(0, 0, 0, .1) rgba(0, 0, 0, .25);
  }
.datetimepicker td.day.active:hover {
  background-color: #0462f7;
  }
.datetimepicker td.day.today:hover,
.datetimepicker td.day.today.active:hover {
  background-color: #d5890e;
  }
.datetimepicker .datetimepicker-hours td span.hour_am,
.datetimepicker .datetimepicker-hours td span.hour_pm {
  width: 14.6%;
  }
.datetimepicker .datetimepicker-hours fieldset legend,
.datetimepicker .datetimepicker-minutes fieldset legend {
  margin-bottom: inherit;
  line-height: 30px;
  }
.datetimepicker td span.disabled,
.datetimepicker td span.disabled:hover {
  color: #999;
  cursor: default;
  background: none;
  }
.datetimepicker td span.active,
.datetimepicker td span.active:hover,
.datetimepicker td span.active.disabled,
.datetimepicker td span.active.disabled:hover {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .25);
  background-color: #3280fc;
  border-color: #0462f7;
  border-color: rgba(0, 0, 0, .1) rgba(0, 0, 0, .1) rgba(0, 0, 0, .25);
  }
.datetimepicker thead tr:first-child th,
.datetimepicker tfoot tr:first-child th {
  cursor: pointer;
  }
.datetimepicker thead tr:first-child th:hover,
.datetimepicker tfoot tr:first-child th:hover {
  background: #eee;
  }
.input-append.date .add-on i,
.input-prepend.date .add-on i,
.input-group.date .input-group-addon span {
  width: 14px;
  height: 14px;
  cursor: pointer;
  }
